nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Scr

Struct Scr 

#[repr(transparent)]
pub struct Scr(pub u32);
SRC Control Register

Tuple Fields

0: u32

Implementations

Source

impl Scr

pub const fn mask_wdog_rst(&self) -> MaskWdogRst

Mask wdog_rst_b source

pub const fn set_mask_wdog_rst(&mut self, val: MaskWdogRst)

Mask wdog_rst_b source

pub const fn core0_rst(&self) -> Core0Rst

Software reset for core0 only

pub const fn set_core0_rst(&mut self, val: Core0Rst)

Software reset for core0 only

pub const fn core0_dbg_rst(&self) -> Core0DbgRst

Software reset for core0 debug only

pub const fn set_core0_dbg_rst(&mut self, val: Core0DbgRst)

Software reset for core0 debug only

pub const fn dbg_rst_msk_pg(&self) -> DbgRstMskPg

Do not assert debug resets after power gating event of core

pub const fn set_dbg_rst_msk_pg(&mut self, val: DbgRstMskPg)

Do not assert debug resets after power gating event of core

pub const fn mask_wdog3_rst(&self) -> MaskWdog3Rst

Mask wdog3_rst_b source

pub const fn set_mask_wdog3_rst(&mut self, val: MaskWdog3Rst)

Mask wdog3_rst_b source